@@ -1,7 +1,7 @@
 package App::DuckPAN;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.199';
+$App::DuckPAN::VERSION = '0.200';
 use feature 'state';
 
 use Moo;
@@ -29,6 +29,12 @@ use App::DuckPAN::Cmd::Help;
 
 no warnings 'uninitialized';
 
+option dev_version => (
+	is => 'ro',
+	default => 9.999,
+	doc => 'Version used when using unreleased code, e.g. git repos'
+);
+
 option dukgo_my_account => (
 	is => 'ro',
 	lazy => 1,
@@ -111,7 +117,7 @@ option duckpan => (
 sub _ua_string {
 	my ($self) = @_;
 	my $class   = ref $self || $self;
-	my $version = $class->VERSION || '9.999';
+	my $version = $class->VERSION || $self->dev_version;
 	return "$class/$version";
 }
 
@@ -313,7 +319,7 @@ sub execute {
 				push @modules, 'App::DuckPAN';
 				if($all_modules){
 					push @modules, 'DDG';
-					unshift @modules, $reinstall_latest if $reinstall_latest; 
+					unshift @modules, $reinstall_latest if $reinstall_latest;
 				}
 			}
 			else {
@@ -361,7 +367,8 @@ sub emit_and_exit {
 
 	if ($exit_code == 0) {      # This is just an info message.
 		$self->emit_info(@msg);
-	} else {                    # But if it's an unhappy exit
+	}
+	else {                    # But if it's an unhappy exit
 		$self->_print_msg(*STDERR, $prefix, @msg);
 	}
 
@@ -393,7 +400,7 @@ sub _print_msg {
 }
 
 sub camel_to_underscore {
- my ($self, $name) = @_;
+	my ($self, $name) = @_;
 	# Replace first capital by lowercase
 	# if followed my lowercase.
 	$name =~ s/^([A-Z])([a-z])/lc($1).$2/ge;
@@ -408,9 +415,9 @@ sub phrase_to_camel {
 
 	$camel =~ s/
 		(?:           # if a character:
-		      \s+     # - follows spaces
-		    | (?<=::) # - or follows ::
-		    | ^       # - or is the first character
+			  \s+     # - follows spaces
+			| (?<=::) # - or follows ::
+			| ^       # - or is the first character
 		)(.)          # (the character)
 		/\U$1/gx;     # then uppercase it (preceding spaces are removed)
 
@@ -421,30 +428,31 @@ sub phrase_to_camel {
 }
 
 sub check_requirements {
-        my ($self) = @_;
+		my ($self) = @_;
 
-        if (!$self->check) {
-                $self->emit_notice("Requirements checking was disabled...");
-                return 1;
-        }
-        my $signal_file = $self->cfg->cache_path->child('perl_checked');
-        my $last_checked_perl = ($signal_file->exists) ? $signal_file->stat->mtime : 0;
-        if ((time - $last_checked_perl) <= $self->cachesec) {
-                $self->emit_debug("Perl module versions recently checked, skipping requirements check...");
-        } else {
-                $self->emit_info("Checking for DuckPAN requirements...");
+		if (!$self->check) {
+				$self->emit_notice("Requirements checking was disabled...");
+				return 1;
+		}
+		my $signal_file = $self->cfg->cache_path->child('perl_checked');
+		my $last_checked_perl = ($signal_file->exists) ? $signal_file->stat->mtime : 0;
+		if ((time - $last_checked_perl) <= $self->cachesec) {
+				$self->emit_debug("Perl module versions recently checked, skipping requirements check...");
+		}
+		else {
+				$self->emit_info("Checking for DuckPAN requirements...");
 
-                $self->emit_and_exit(1, 'Requirements check failed')
-                  unless (
-                        $self->check_perl &&
-                        $self->check_app_duckpan &&
-                        $self->check_ddg &&
-                        $self->check_ssh &&
-                        $self->check_git);
-        }
-        $signal_file->touch;
+				$self->emit_and_exit(1, 'Requirements check failed')
+				  unless (
+						$self->check_perl &&
+						$self->check_app_duckpan &&
+						$self->check_ddg &&
+						$self->check_ssh &&
+						$self->check_git);
+		}
+		$signal_file->touch;
 
-        return 1;
+		return 1;
 }
 
 sub get_local_ddg_version {
@@ -467,14 +475,17 @@ sub check_git {
 		if ($version_string =~ m/git version (\d+)\.(\d+)/) {
 			if ($1 <= 1 && $2 < 7) {
 				$self->emit_error("require minimum git 1.7");
-			} else {
+			}
+			else {
 				$self->emit_debug($git);
 				$ok = 1;
 			}
-		} else {
+		}
+		else {
 			$self->emit_error("Unknown git version!");
 		}
-	} else {
+	}
+	else {
 		$self->emit_error("git not found");
 	}
 	return $ok;
@@ -487,7 +498,8 @@ sub check_ssh {
 	if (my $ssh = which('ssh')) {
 		$self->emit_debug($ssh);
 		$ok = 1;
-	} else {
+	}
+	else {
 		$self->emit_error('ssh not found');
 	}
 	return $ok;
@@ -508,10 +520,12 @@ sub check_perl {
 	if ($installed_version->vcmp($perl_versions{required}) < 0) {
 		$self->emit_error('perl ' . $perl_versions{required}->normal . ' or higher is required. ', $installed_version->normal . ' is installed.');
 		$ok = 0;
-	} elsif ($installed_version->vcmp($perl_versions{recommended}) < 0) {
+	}
+	elsif ($installed_version->vcmp($perl_versions{recommended}) < 0) {
 		$self->emit_notice('perl ' . $perl_versions{recommended}->normal . ' or higher is recommended. ',
 			$installed_version->normal . " is installed.");
-	} else {
+	}
+	else {
 		$self->emit_debug($installed_version->normal);
 	}
 
@@ -523,7 +537,7 @@ sub check_app_duckpan {
 	my $ok                = 1;
 	my $pin_version       = $ENV{"DuckPAN"} || undef;
 	my $installed_version = $self->get_local_app_duckpan_version;
-	return $ok if $installed_version && $installed_version == '9.999';
+	return $ok if $installed_version && $installed_version == $self->dev_version;
 	$self->emit_info("Checking for latest App::DuckPAN... ");
 	my $packages = $self->duckpan_packages;
 	my $module   = $packages->package('App::DuckPAN');
@@ -534,7 +548,8 @@ sub check_app_duckpan {
 		my $msg = "App::DuckPAN version: $installed_version";
 		$msg .= " (duckpan has " . $module->version . ")" if $installed_version ne $module->version;
 		$self->emit_debug($msg);
-	} else {
+	}
+	else {
 		my @msg = (
 			"You have version $installed_version, latest is " . $module->version . "!",
 			"Please install the latest App::DuckPAN package with: duckpan upgrade"
@@ -549,7 +564,8 @@ sub check_ddg {
 	my $ok                = 1;
 	my $pin_version       = $ENV{"DDG"} || undef;
 	my $installed_version = $self->get_local_ddg_version;
-	return $ok if $installed_version && $installed_version == '9.999';
+	return $ok if $installed_version && $installed_version == $self->dev_version;
+	warn "installing DDG";
 	$self->emit_info("Checking for latest DDG Perl package...");
 	my $packages = $self->duckpan_packages;
 	my $module   = $packages->package('DDG');
@@ -560,20 +576,23 @@ sub check_ddg {
 		my $msg = "DDG version: $installed_version";
 		$msg .= " (duckpan has $latest_version )" if $installed_version ne $latest_version;
 		$self->emit_debug($msg);
-	} elsif ($pin_version && $pin_version < $latest_version){
+	}
+	elsif ($pin_version && $pin_version < $latest_version){
 			my @msg = (
 				"A newer version of DDG exists: $latest_version.",
 				"You have the version pinned to: $pin_version. Please update your version pin!"
 			);
 			$self->emit_notice(@msg);
-	} else {
+	}
+	else {
 		if ($installed_version) {
 			my @msg = (
 				"You have version $installed_version, latest is " . $module->version . "!",
 				"Please install the latest DDG package with: duckpan DDG"
 			);
 			$self->emit_notice(@msg);
-		} else {
+		}
+		else {
 			$self->perl->duckpan_install('DDG');
 		}
 	}
@@ -632,7 +651,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 DuckPAN
 
