@@ -1,20 +1,21 @@
 package App::DuckPAN::Cmd::Env::Cmd::List;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: List all env variables
-$App::DuckPAN::Cmd::Env::Cmd::List::VERSION = '0.199';
+$App::DuckPAN::Cmd::Env::Cmd::List::VERSION = '0.200';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
 use MooX::Options protect_argv => 0;
 
 sub run {
-    my ( $self )  = @_;
-    my $data = $self->env->load_env_ini;
-    if (keys %{$data}) {
-        $self->root->emit_info("export ". $_ ."=". $data->{$_} ) for (sort keys %{$data});
-    } else {
-        $self->root->emit_notice("There are no env variables set currently.");
-    }
+	my ( $self )  = @_;
+	my $data = $self->env->load_env_ini;
+	if (keys %{$data}) {
+		$self->root->emit_info("export ". $_ ."=". $data->{$_} ) for (sort keys %{$data});
+	}
+	else {
+		$self->root->emit_notice("There are no env variables set currently.");
+	}
 }
 
 1;
@@ -29,7 +30,7 @@ App::DuckPAN::Cmd::Env::Cmd::List - List all env variables
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
