@@ -1,7 +1,7 @@
 package App::DuckPAN::Cmd::New;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Take a name as input and generates a new, named Goodie or Spice instant answer skeleton
-$App::DuckPAN::Cmd::New::VERSION = '0.199';
+$App::DuckPAN::Cmd::New::VERSION = '0.200';
 # See the template/templates.yml file in the Goodie or Spice repository for the
 # list of template-sets and files generated for them
 
@@ -76,7 +76,8 @@ sub _build__template_defs {
 				"Template definitions file not found for " . $type->{name} .
 				" Instant Answers. You may need to pull the latest version " .
 				"of this repository.");
-		} else {
+		}
+		else {
 			$self->app->emit_and_exit(-1, $error);
 		}
 	};
@@ -183,7 +184,8 @@ sub run {
 			$name    = pop @path_parts;
 			$path    = join("/", @path_parts);
 			$lc_path = join("/", map { $self->app->camel_to_underscore($_) } @path_parts);
-		} else {
+		}
+		else {
 			$self->app->emit_and_exit(-1, "Malformed input. Please provide a properly formatted package name for your Instant Answer.");
 		}
 	}
@@ -304,7 +306,7 @@ App::DuckPAN::Cmd::New - Take a name as input and generates a new, named Goodie
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
