@@ -1,7 +1,7 @@
 package App::DuckPAN::Cmd::Roadrunner;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Install requirements as fast as possible
-$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.199';
+$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.200';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -18,11 +18,13 @@ sub run {
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil listdeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm --quiet --notest --skip-satisfied"));
 		$self->app->emit_info("Everything fine!");
-	} elsif (-f 'Makefile.PL') {
+	}
+	elsif (-f 'Makefile.PL') {
 		$self->app->emit_info("Found a Makefile.PL");
 		$self->app->perl->cpanminus_install_error
 			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
-	} elsif (-f 'Build.PL') {
+	}
+	elsif (-f 'Build.PL') {
 		$self->app->emit_info("Found a Build.PL");
 		$self->app->perl->cpanminus_install_error
 			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
@@ -44,7 +46,7 @@ App::DuckPAN::Cmd::Roadrunner - Install requirements as fast as possible
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
