@@ -1,7 +1,7 @@
 package App::DuckPAN::Cmd::Setup;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Setting up your duck.co Account on your duckpan client
-$App::DuckPAN::Cmd::Setup::VERSION = '0.199';
+$App::DuckPAN::Cmd::Setup::VERSION = '0.200';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -106,11 +106,13 @@ sub setup_name {
 	my $name = $self->get_name;
 	if ($name) {
 		$self->name($name);
-	} else {
+	}
+	else {
 		$self->app->emit_info("We need some kind of name!");
 		if ($self->app->term->ask_yn( prompt => 'Wanna try again? ', default => 'y' )) {
 			$self->setup_name;
-		} else {
+		}
+		else {
 			$self->app->emit_and_exit(1, "A name is required to work with DuckPAN");
 		}
 	}
@@ -121,11 +123,13 @@ sub setup_email {
 	my $email = $self->get_email;
 	if (Email::Valid->address($email)) {
 		$self->email($email);
-	} else {
+	}
+	else {
 		$self->app->emit_info("No valid email given!");
 		if ($self->app->term->ask_yn( prompt => 'Wanna try again? ', default => 'y' )) {
 			$self->setup_email;
-		} else {
+		}
+		else {
 			$self->app->emit_and_exit(1, "An email is required to work with DuckPAN");
 		}
 	}
@@ -139,12 +143,14 @@ sub setup_dukgo {
 	if ($self->app->checking_dukgo_user($user,$pass)) {
 		$self->user($user);
 		$self->pass($pass);
-	} else {
+	}
+	else {
 		$self->app->emit_info("Account lookup failed!");
 		if ($self->app->term->ask_yn( prompt => 'Wanna try again? ', default => 'y' )) {
 			$self->clear_user if $self->has_user;
 			$self->setup_dukgo;
-		} else {
+		}
+		else {
 			$self->app->emit_and_exit(1, "A login to https://duck.co/ is required to work with DuckPAN");
 		}
 	}
@@ -177,7 +183,7 @@ App::DuckPAN::Cmd::Setup - Setting up your duck.co Account on your duckpan clien
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
