@@ -1,7 +1,7 @@
 package App::DuckPAN::WebPublisher;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan publisher
-$App::DuckPAN::WebPublisher::VERSION = '0.199';
+$App::DuckPAN::WebPublisher::VERSION = '0.200';
 use Moo;
 with qw( App::DuckPAN::HasApp );
 
@@ -76,13 +76,15 @@ sub request {
 		$body = $site->fullpath_files->{$file}->uncached_content;
 		$response->code("200");
 		$response->content_type('text/html; charset=utf-8');
-	} else {
+	}
+	else {
 		my $res = $self->app->http->request(HTTP::Request->new(GET => $url.$request->request_uri));
 		if ($res->is_success) {
 			$body = $res->decoded_content;
 			$response->code($res->code);
 			$response->content_type($res->content_type);
-		} else {
+		}
+		else {
 			$body = "GET ".$url.$request->request_uri.": ".$res->status_line;
 			warn $body, "\n";
 		}
@@ -108,7 +110,7 @@ App::DuckPAN::WebPublisher - Webserver for duckpan publisher
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
