@@ -1,7 +1,7 @@
 package App::DuckPAN::WebStatic;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan static
-$App::DuckPAN::WebStatic::VERSION = '0.199';
+$App::DuckPAN::WebStatic::VERSION = '0.200';
 use Moo;
 use HTTP::Request;
 use Plack::Request;
@@ -75,13 +75,15 @@ sub request {
 		$body = path($site->{urls}->{$request->request_uri}->{$locale})->slurp_utf8;
 		$response->code("200");
 		$response->content_type('text/html');
-	} else {
+	}
+	else {
 		my $res = $self->ua->request(HTTP::Request->new(GET => $site->{base_url}.$request->request_uri));
 		if ($res->is_success) {
 			$body = $res->decoded_content;
 			$response->code($res->code);
 			$response->content_type($res->content_type);
-		} else {
+		}
+		else {
 			warn $res->status_line, "\n";
 			$body = "";
 		}
@@ -107,7 +109,7 @@ App::DuckPAN::WebStatic - Webserver for duckpan static
 
 =head1 VERSION
 
-version 0.199
+version 0.200
 
 =head1 AUTHOR
 
